@@ -12,6 +12,7 @@ OC.L10N.register(
     "Day" : "Dag",
     "Week" : "Week",
     "Month" : "Maand",
+    "List" : "Lys",
     "Download" : "Laai af",
     "Delete" : "Skrap",
     "Share link" : "Deel skakel",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Filename" : "Lêernaam",
     "Cancel" : "Kanselleer",
     "Automatic" : "Outomaties",
+    "Actions" : "Aksies",
     "Show week numbers" : "Toon weeknommers",
     "Notification" : "Kennisgewing",
     "Email" : "E-pos",
@@ -35,12 +37,10 @@ OC.L10N.register(
     "More" : "Nog",
     "Save" : "Stoor",
     "Update" : "Werk by",
-    "Select Date" : "Kies Datum",
     "Personal" : "Persoonlik",
     "Details" : "Details",
     "Attendees" : "Bywoners",
     "Reminders" : "Herinneringe",
-    "Activity" : "Aktiwiteit",
     "Close" : "Sluit",
     "Anniversary" : "Herdenking",
     "Week {number} of {year}" : "Week {number} van {year}",
@@ -50,7 +50,6 @@ OC.L10N.register(
     "Description" : "Beskrywing",
     "Confirmed" : "Bevestig",
     "Tentative" : "Tentatief",
-    "Cancelled" : "Gekanselleer",
     "Categories" : "Kategorieë",
     "Mail" : "Pos",
     "Play" : "Speel Af",
