@@ -82,6 +82,7 @@ OC.L10N.register(
     "Filename" : "اسم الملف",
     "Calendar to import into" : "تقويم للاستيراد اليه",
     "Cancel" : "إلغاء",
+    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
     "Automatic" : "تلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
@@ -122,6 +123,7 @@ OC.L10N.register(
     "on" : "في",
     "at" : "في",
     "+ Add reminder" : "+ اضافة تذكير",
+    "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
     "No reminders yet" : "لا يوجد تذكير بعد",
     "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
     "Busy (tentative)" : "مشغول (حاليا)",
@@ -176,6 +178,7 @@ OC.L10N.register(
     "Repeat every" : "تكرار كل",
     "By day of the month" : "يوم من الشهر",
     "On the" : "في الـ",
+    "_year_::_years_" : ["سنه","سنه","سنه","سنوات","سنوات","سنوات"],
     "Monday" : "الإثنين",
     "weekday" : "ايام الاسبوع",
     "weekend day" : "يوم نهاية الاسبوع",
