@@ -27,9 +27,9 @@ OC.L10N.register(
     "List" : "Llista",
     "Untitled calendar" : "Calendari sense títol",
     "Edit name" : "Edita nom",
-    "Saving name …" : "Desant el nom …",
+    "Saving name …" : "S'està desant el nom …",
     "Edit color" : "Edita color",
-    "Saving color …" : "Desant el color …",
+    "Saving color …" : "S'està desant el color …",
     "Copy private link" : "Copia l'enllaç privat",
     "Download" : "Baixa",
     "Unshare from me" : "Deixa de compartir",
@@ -40,25 +40,25 @@ OC.L10N.register(
     "Calendar link could not be copied to clipboard." : "No s'ha pogut copiar l'enllaç del calendari al porta-retalls.",
     "An error occurred, unable to rename the calendar." : "S'ha produït un error. No s'ha canviat el nom del calendari.",
     "An error occurred, unable to change the calendar's color." : "S'ha produït un error. No s'ha canviat el color del calendari.",
-    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","Deixant de compartir el calendari en {countdown} segons"],
-    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","Eliminant el calendari en {countdown} segons"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","S'està deixant de compartir el calendari en {countdown} segons"],
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","S'està suprimint el calendari en {countdown} segons"],
     "Share link" : "Enllaç de compartició",
     "Publish calendar" : "Publicar el calendari",
-    "Publishing calendar" : "Publicant el calendari",
+    "Publishing calendar" : "S'està publicant el calendari",
     "Copy public link" : "Copiar l'enllaç públic",
     "Send link to calendar via email" : "Enviar per correu l'enllaç al calendari",
     "Enter one address" : "Escriure una adreça",
-    "Sending email …" : "Envian correu …",
+    "Sending email …" : "S'està enviant el correu …",
     "Copy subscription link" : "Copiar l'enllaç de subscripció",
-    "Copying link …" : "Copiant l'enllaç …",
+    "Copying link …" : "S'està copiant l'enllaç …",
     "Copied link" : "Enllaç copiat",
     "Could not copy link" : "No s'ha pogut copiar l'enllaç",
     "Copy embedding code" : "Copiar el codi per inserir",
-    "Copying code …" : "Copiant el codi …",
+    "Copying code …" : "S'està copiant el codi …",
     "Copied code" : "Codi copiat",
     "Could not copy code" : "No s'ha pogut copiar el codi",
     "Delete share link" : "Suprimeix l'enllaç de compartició",
-    "Deleting share link …" : "Eliminant l'enllaç de compartició …",
+    "Deleting share link …" : "S'està suprimint l'enllaç de compartició …",
     "An error occurred, unable to publish calendar." : "Ha succeït un error i no ha estat possible publicar el calendari.",
     "An error occurred, unable to send email." : "Ha succeït un error i no ha estat possible enviar el correu.",
     "Embed code copied to clipboard." : "S'ha copiat el codi al porta-retalls.",
@@ -72,10 +72,10 @@ OC.L10N.register(
     "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
     "+ New calendar" : "+ Calendari nou",
     "New calendar" : "Calendari nou",
-    "Creating calendar …" : "Creant el calendari …",
+    "Creating calendar …" : "S'està creant el calendari …",
     "New calendar with task list" : "Nou calendari amb llista de tasques",
     "New subscription from link (read-only)" : "Nova subscripció des d'enllaç (només lectura)",
-    "Creating subscription …" : "Creant la subscripció …",
+    "Creating subscription …" : "S'està creant la subscripció …",
     "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
@@ -84,7 +84,7 @@ OC.L10N.register(
     "Filename" : "Nom del fitxer",
     "Calendar to import into" : "Calendari a importar",
     "Cancel" : "Cancel·la",
-    "_Import calendar_::_Import calendars_" : ["Importar calendari","Importar calendaris"],
+    "_Import calendar_::_Import calendars_" : ["Importar calendari","Importa calendaris"],
     "{filename} is an unsupported file-type" : "{filename} és un tipus de fitxer no compatible amb aquesta aplicació",
     "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
     "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
@@ -105,14 +105,14 @@ OC.L10N.register(
     "Actions" : "Accions",
     "Create event" : "Crea un esdeveniment",
     "Show shortcuts" : "Mostra les dreceres",
-    "Enable birthday calendar" : "Habilitar calendari d'aniversaris",
-    "Show tasks in calendar" : "Mostrar tasques al calendari",
-    "Enable simplified editor" : "Habilitar l'editor simplificat",
-    "Limit visible events per view" : "Limitar el nombre d'events visibles per vista",
-    "Show weekends" : "Mostrar caps de setmana",
+    "Enable birthday calendar" : "Activa el calendari d'aniversaris",
+    "Show tasks in calendar" : "Mostra tasques al calendari",
+    "Enable simplified editor" : "Activa l'editor simplificat",
+    "Limit visible events per view" : "Limita el nombre d'esdeveniments visibles per vista",
+    "Show weekends" : "Mostra els caps de setmana",
     "Show week numbers" : "Mostra el número de la setmana",
-    "Copy primary CalDAV address" : "Copiar l'adreça CalDEV primària",
-    "Copy iOS/macOS CalDAV address" : "Copiar l'adreça CalDAV iOS/macOS",
+    "Copy primary CalDAV address" : "Copia l'adreça CalDEV primària",
+    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Mostra les tecles de drecera",
     "Settings & import" : "Paràmetres i importació",
     "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
@@ -124,12 +124,12 @@ OC.L10N.register(
     "Other notification" : "Altres notificacions",
     "Relative to event" : "En relació a l'event",
     "On date" : "A la data",
-    "Edit time" : "Modificar l'hora",
+    "Edit time" : "Modifica l'hora",
     "Save time" : "Desar l'hora",
-    "Remove reminder" : "Eliminar el recordatori",
+    "Remove reminder" : "Suprimeix el recordatori",
     "on" : "a",
     "at" : "a",
-    "+ Add reminder" : "+ Afegir un recordatori",
+    "+ Add reminder" : "+ Afegeix un recordatori",
     "_second_::_seconds_" : ["segon","segons"],
     "_minute_::_minutes_" : ["minut","minuts"],
     "_hour_::_hours_" : ["hora","hores"],
@@ -150,20 +150,20 @@ OC.L10N.register(
     "{name} did not respond to your invitation yet." : "{name} encara no ha respost a la vostra invitació.",
     "{name} did not respond to {organizerName}'s invitation yet." : "{name} encara no ha respost a la invitació de {organizerName}.",
     "Create Talk room for this event" : "Crear una sala a Talk per a aquest event",
-    "Show busy times" : "Mostrar els horaris ocupats",
+    "Show busy times" : "Mostra els horaris ocupats",
     "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala del Talk a la descripció de l'event.",
     "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
-    "Send e-mail" : "Enviar correu",
-    "Chairperson" : "Convocant",
+    "Send e-mail" : "Envia el correu",
+    "Chairperson" : "S'està convocant",
     "Required participant" : "Participant necessari",
     "Optional participant" : "Participant opcional",
     "Non-participant" : "No-participant",
-    "Remove attendee" : "Treure participant",
-    "Search for e-mails, users, contacts, resources or rooms" : "Cercar correus, usuaris, contactes, recursos o espais",
+    "Remove attendee" : "Treu el participant",
+    "Search for e-mails, users, contacts, resources or rooms" : "Cerca correus, usuaris, contactes, recursos o espais",
     "No match found" : "No s'ha trobat res",
     "No attendees yet" : "Encara sense participants",
     "(organizer)" : "(organitzador)",
-    "Remove color" : "Treure color",
+    "Remove color" : "Treu el color",
     "Event title" : "Títol de l'event",
     "All day" : "Tot el dia",
     "Can not modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la opció de dia-sencer pels events que formen part d'un conjunt recurrent.",
@@ -171,7 +171,7 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "de {startDate} a {startTime}",
     "to {endDate}" : "fins al {endDate}",
     "to {endDate} at {endTime}" : "fins al {endDate} a les {endTime}",
-    "End repeat" : "Finalitzar repetició",
+    "End repeat" : "Finalitza la repetició",
     "Select to end repeat" : "Seleccioneu per finalitzar repetició",
     "never" : "mai",
     "on date" : "a temps",
@@ -199,13 +199,13 @@ OC.L10N.register(
     "More" : "Més",
     "Save" : "Desa",
     "Update" : "Actualitza",
-    "Update this occurrence" : "Actualitzar aquesta ocurrència",
-    "Update this and all future" : "Actualitzar aquesta i les futures",
+    "Update this occurrence" : "Actualitza aquesta ocurrència",
+    "Update this and all future" : "Actualitza aquesta i les futures",
     "Public calendar does not exist" : "No existeix un calendari públic",
     "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
-    "Please select a timezone:" : "Escollir una zona horària:",
-    "Pick a time" : "Escollir una hora",
-    "Pick a date" : "Escollir una data",
+    "Please select a timezone:" : "Selecciona un fus horari",
+    "Pick a time" : "Tria una hora",
+    "Pick a date" : "Tria una data",
     "from {formattedDate}" : "de {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -213,29 +213,29 @@ OC.L10N.register(
     "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
     "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
     "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
-    "Please enter a valid date" : "Escriure una data vàlida",
-    "Please enter a valid date and time" : "Escriure una data i hora vàlides",
-    "Type to search timezone" : "Començar a escriure per cercar una zona horària",
+    "Please enter a valid date" : "Si us plau, escriu una data vàlida",
+    "Please enter a valid date and time" : "Si us plau, escriu una data i hora vàlides",
+    "Type to search timezone" : "Comença a escriure per cercar un fus horari",
     "Personal" : "Personal",
     "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "La detecció automàtica de zona horària ha establert que la vostra zona horària és UTC.\nAixò probablement és el resultat d'una mesura de seguretat del vostre navegador web.\nEstabliu la vostra zona horària manualment a la configuració del calendari.",
     "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "No s'ha trobat la zona horària que heu establert ({timezoneId}) . Així que se us ha retornat a la UTC.\nDefiniu la vostra zona horària a la configuració i si us plau informeu d'aquest problema.",
     "No more events today" : "Avui no hi ha més esdeveniments",
     "No upcoming events" : "No hi ha propers esdeveniments",
-    "Create a new event" : "Crear un esdeveniment nou",
+    "Create a new event" : "Crea un esdeveniment nou",
     "[Today]" : "[Avui]",
     "[Tomorrow]" : "[Demà]",
     "[Yesterday]" : "[Ahir]",
     "[Last] dddd" : "[Últim] dddd",
     "Event does not exist" : "L'esdeveniment no existeix",
-    "Delete this occurrence" : "Esborrar aquesta ocurrència",
-    "Delete this and all future" : "Esborrar aquest i les ocurrències futures",
+    "Delete this occurrence" : "Suprimeix aquesta ocurrència",
+    "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
     "Details" : "Detalls",
     "Attendees" : "Assistents",
     "Reminders" : "Recordatoris",
     "Close" : "Tanca",
-    "Show more details" : "Mostrar més detalls",
+    "Show more details" : "Mostra'n més detalls",
     "Subscribe to {name}" : "Subscriure a {name}",
-    "Download {name}" : "Baixar {name}",
+    "Download {name}" : "Baixa {name}",
     "Anniversary" : "Commemoració",
     "Appointment" : "Cita",
     "Business" : "Negocis",
@@ -294,7 +294,7 @@ OC.L10N.register(
     "No events to display" : "No hi ha esdeveniments per visualitzar",
     "_+%n more_::_+%n more_" : ["+%n més","+%n més"],
     "No events" : "Cap esdeveniment",
-    "Create a new event or change the visible time-range" : "Crear un esdeveniment nou o canviar l'interval de temps visible",
+    "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
     "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
     "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
     "When shared show" : "Mostrar a compartits",
@@ -303,7 +303,7 @@ OC.L10N.register(
     "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
     "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
     "Location" : "Ubicació",
-    "Add a location" : "Afegir una ubicació",
+    "Add a location" : "Afegeix una ubicació",
     "Description" : "Descripció",
     "Add a description" : "Afegir una descripció",
     "Status" : "Estat",
@@ -311,7 +311,7 @@ OC.L10N.register(
     "Tentative" : "Provisional",
     "Canceled" : "Cancel·lat",
     "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'event.",
-    "Show as" : "Mostrar com",
+    "Show as" : "Mostra com",
     "Take this event into account when calculating free-busy information." : "Tenir en compte aquest event quan es calculi informació sobre disponibilitat-ocupació.",
     "Free" : "Lliure",
     "Categories" : "Categories",
