@@ -70,6 +70,8 @@ OC.L10N.register(
     "Cancel" : "Annullér",
     "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
     "Automatic" : "Automatisk",
+    "or" : "eller",
+    "Actions" : "Handlinger",
     "Enable birthday calendar" : "Slå fødselsdagskalender til",
     "Enable simplified editor" : "Slå simpel editor til",
     "Show weekends" : "Vis weekender",
@@ -111,19 +113,18 @@ OC.L10N.register(
     "More" : "Mere",
     "Save" : "Gem",
     "Update" : "Opdatér",
-    "Select Date" : "Vælg dato",
     "Personal" : "Personlig",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
     "Reminders" : "Påmindelser",
-    "Activity" : "Aktivitet",
-    "Projects" : "Projekter",
     "Close" : "Luk",
     "Anniversary" : "Årsdag",
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Daily" : "Dagligt",
     "Weekly" : "Ugentligt",
     "Untitled event" : "Unavngiven begivenhed",
+    "next year" : "næste år",
+    "today" : "i dag",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
     "When shared hide this event" : "Når delt, skjul denne begivenhed",
@@ -132,7 +133,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "Bekræftet",
     "Tentative" : "Foreløbig",
-    "Cancelled" : "Annulléret",
     "Categories" : "Kategorier",
     "Presentation" : "Præsentation",
     "Movie" : "Film",
