@@ -104,7 +104,7 @@ OC.L10N.register(
     "Enable birthday calendar" : "Születésnapokat tartalamzó naptár engedélyezése",
     "Show tasks in calendar" : "Feladatok mutatása a naptárban",
     "Enable simplified editor" : "Egyszerűsített szerkesztő engedélyezése",
-    "Limit visible events per view" : "Látható események számának limitálása nézetenként",
+    "Limit visible events per view" : "Látható események számának korlátozása nézetenként",
     "Show weekends" : "Hétvégék mutatása",
     "Show week numbers" : "Hetek számának megjelenítése",
     "Copy primary CalDAV address" : "Elsődleges CalDAV cím másolása",
@@ -158,7 +158,6 @@ OC.L10N.register(
     "No match found" : "Nem található egyezés",
     "No attendees yet" : "Nincs még résztvevő",
     "(organizer)" : "(szervező)",
-    "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "A meghívók kiküldéséhez és a válaszok kezeléséhez [linkopen]adja hozzá e-mail címét a személyes beállításokhoz[linkclose].",
     "Remove color" : "Szín eltávolítása",
     "Event title" : "Esemény cím",
     "All day" : "Egész napos",
