@@ -179,6 +179,7 @@ OC.L10N.register(
     "second to last" : "2日目から最終日",
     "last" : "最後",
     "Repeat" : "繰り返し",
+    "Repeat every" : "毎日繰り返す",
     "_month_::_months_" : ["月"],
     "_year_::_years_" : ["年"],
     "Monday" : "月曜日",
@@ -249,6 +250,7 @@ OC.L10N.register(
     "_%n time_::_%n times_" : ["%n回"],
     "Untitled event" : "無題のイベント",
     "Untitled task" : "タイトルなしタスク",
+    "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
     "prev" : "前へ",
     "next" : "次へ",
     "prev year" : "前の年へ",
@@ -256,7 +258,7 @@ OC.L10N.register(
     "today" : "今日",
     "list" : "リスト",
     "W" : "W",
-    "all-day" : "一日中",
+    "all-day" : "終日",
     "No events to display" : "表示するイベントはありません",
     "No events" : "イベントはありません",
     "When shared show full event" : "共有時にすべてのイベントを表示",
