@@ -8,6 +8,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
     "Open »%s«" : "Åpne \"%s\"",
     "Cheers!" : "Ha det!",
+    "Upcoming events" : "Kommende hendelser",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
     "Previous day" : "Forrige dag",
@@ -208,6 +209,7 @@ OC.L10N.register(
     "Type to search timezone" : "Skriv for å finne tidssone",
     "Personal" : "Personlig",
     "No more events today" : "Ingen flere hendelser i dag",
+    "Event does not exist" : "Avtalen finnes ikke",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "Details" : "Detaljer",
@@ -241,6 +243,8 @@ OC.L10N.register(
     "Untitled task" : "Oppgave uten tittel",
     "next year" : "neste år",
     "today" : "i dag",
+    "all-day" : "Heldags",
+    "No events" : "Ingen hendelser",
     "When shared show" : "Når delt vis",
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
