@@ -11,6 +11,7 @@ OC.L10N.register(
     "Day" : "Ditë",
     "Week" : "Javë",
     "Month" : "Muaj",
+    "List" : "List",
     "Download" : "Shkarkoje",
     "Delete" : "Fshije",
     "Share link" : "Ndani lidhjen",
@@ -39,12 +40,12 @@ OC.L10N.register(
     "Details" : "Detajet",
     "Attendees" : "Pjesëmarrës",
     "Reminders" : "Kujtues",
-    "Activity" : "Aktiviteti",
     "Close" : "Mbylle",
     "Anniversary" : "Përvjetor",
     "Week {number} of {year}" : "Java e {number} e {year}",
     "Daily" : "Përditë",
     "Weekly" : "Çdo javë",
+    "today" : "sot",
     "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
     "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
     "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
@@ -53,7 +54,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "E konfirmuar",
     "Tentative" : "Tentativë",
-    "Cancelled" : "U anulua",
     "Categories" : "Kategoritë",
     "Presentation" : "Paraqitje",
     "Office" : "Zyrë",
